@@ -1,6 +1,6 @@
 import uuid
 from abc import ABCMeta, abstractmethod
-from typing import List, Type, get_origin, get_args
+from typing import List, Type, get_origin, get_args, TYPE_CHECKING
 import os
 import re
 import time
@@ -19,6 +19,9 @@ from efootprint.utils.object_relationships_graphs import build_object_relationsh
     USAGE_PATTERN_VIEW_CLASSES_TO_IGNORE
 from efootprint.utils.tools import get_init_signature_params
 
+if TYPE_CHECKING:
+    from efootprint.abstract_modeling_classes.contextual_modeling_object_attribute import ContextualModelingObjectAttribute
+
 compute_times = defaultdict(float)
 
 
@@ -263,8 +266,11 @@ class ModelingObject(metaclass=ABCAfterInitMeta):
                     raise ValueError(
                         f"Setting {name} as {input_value} is not possible because {dependent_attribute_value}"
                         f" is not in the list of possible values for {dependent_attribute} "
-                        f"when {name} is {input_value}: "
-                        f"{self.conditional_list_values[dependent_attribute]['conditional_list_values'][input_value]}"
+                        f"when {name} is {input_value}."
+                        f"\nYou might want to use the ModelingUpdate object to be able to change both inputs "
+                        f"at the same time."
+                        f"\nList of possible values for {input_value}:"
+                        f"\n{self.conditional_list_values[dependent_attribute]['conditional_list_values'][input_value]}"
                     )
 
     @property
@@ -464,8 +470,8 @@ class ModelingObject(metaclass=ABCAfterInitMeta):
                 f"You can’t delete {self.name} because "
                 f"{','.join([mod_obj.name for mod_obj in self.modeling_obj_containers])} have it as attribute.")
 
-        for attr in self.mod_obj_attributes:
-            attr.set_modeling_obj_container(None, None)
+        for contextual_attr in self.mod_obj_attributes:
+            contextual_attr.set_modeling_obj_container(None, None)
         for attr_value in get_instance_attributes(self, ObjectLinkedToModelingObj).values():
                 attr_value.set_modeling_obj_container(None, None)
 
@@ -547,3 +553,10 @@ class ModelingObject(metaclass=ABCAfterInitMeta):
                 output_str += "  " + key_value_to_str(key, getattr(self, key))
 
         return output_str
+
+    @property
+    def attribute_update_entanglements(self):
+        # Used to generate new changes that depend on a change in certain attributes
+        # Used in RecurrentEdgeProcess class for generating entanglements so that whenever device is updated,
+        # component needs are updated too.
+        return {}
\ No newline at end of file
