@@ -4,14 +4,14 @@ from typing import Dict, List, Optional
 from efootprint.abstract_modeling_classes.explainable_object_dict import ExplainableObjectDict
 from efootprint.abstract_modeling_classes.modeling_object import ModelingObject
 from efootprint.constants.units import u
-from efootprint.core.hardware.edge_computer import EdgeComputer
-from efootprint.core.hardware.edge_device_base import EdgeDeviceBase
-from efootprint.core.hardware.edge_storage import EdgeStorage
+from efootprint.builders.hardware.edge.edge_computer import EdgeComputer
+from efootprint.core.hardware.edge.edge_device import EdgeDevice
+from efootprint.core.hardware.edge.edge_storage import EdgeStorage
 from efootprint.core.hardware.network import Network
 from efootprint.core.hardware.server import Server
 from efootprint.core.hardware.storage import Storage
-from efootprint.core.usage.edge_usage_journey import EdgeUsageJourney
-from efootprint.core.usage.edge_usage_pattern import EdgeUsagePattern
+from efootprint.core.usage.edge.edge_usage_journey import EdgeUsageJourney
+from efootprint.core.usage.edge.edge_usage_pattern import EdgeUsagePattern
 from efootprint.core.usage.usage_pattern import UsagePattern
 from efootprint.core.usage.usage_journey import UsageJourney
 from efootprint.abstract_modeling_classes.explainable_hourly_quantities import ExplainableHourlyQuantities
@@ -111,12 +111,16 @@ class System(ModelingObject):
         output_list = self.edge_storages + edge_usage_patterns
         edge_usage_journeys = self.edge_usage_journeys
         edge_functions = list(set(sum([euj.edge_functions for euj in edge_usage_journeys], start=[])))
-        recurrent_edge_resource_needs = list(
-            set(sum([ef.recurrent_edge_resource_needs for ef in edge_functions], start=[])))
+        recurrent_edge_device_needs = list(
+            set(sum([ef.recurrent_edge_device_needs for ef in edge_functions], start=[])))
+        recurrent_edge_component_needs = list(
+            set(sum([redn.recurrent_edge_component_needs for redn in recurrent_edge_device_needs], start=[])))
         edge_devices = self.edge_devices
+        edge_devices_components = list(set(sum([ed.components for ed in edge_devices], start=[])))
         countries = list(set([up.country for up in edge_usage_patterns]))
-        all_modeling_objects = (output_list + edge_usage_journeys + edge_functions + recurrent_edge_resource_needs
-                                + edge_devices + countries)
+        all_modeling_objects = (
+                output_list + edge_usage_journeys + edge_functions + recurrent_edge_device_needs
+                + recurrent_edge_component_needs + edge_devices + edge_devices_components + countries)
 
         return all_modeling_objects
 
@@ -138,7 +142,7 @@ class System(ModelingObject):
         return list(set(sum([usage_pattern.usage_journey.servers for usage_pattern in self.usage_patterns], start=[])))
 
     @property
-    def edge_devices(self) -> List[EdgeDeviceBase]:
+    def edge_devices(self) -> List[EdgeDevice]:
         return list(set(sum([euj.edge_devices for euj in self.edge_usage_journeys], start=[])))
 
     @property
@@ -151,7 +155,12 @@ class System(ModelingObject):
 
     @property
     def edge_storages(self) -> List[EdgeStorage]:
-        return list(set([edge_computer.storage for edge_computer in self.edge_computers]))
+        edge_storages = []
+        for edge_device in self.edge_devices:
+            for component in edge_device.components:
+                if isinstance(component, EdgeStorage):
+                    edge_storages.append(component)
+        return list(set(edge_storages))
 
     @property
     def networks(self) -> List[Network]:
@@ -175,8 +184,6 @@ class System(ModelingObject):
                         for usage_pattern in self.usage_patterns},
             "EdgeDevices": {edge_device: edge_device.instances_fabrication_footprint
                             for edge_device in self.edge_devices},
-            "EdgeStorage": {edge_storage: edge_storage.instances_fabrication_footprint
-                             for edge_storage in self.edge_storages},
         }
 
         return fab_footprints
@@ -191,7 +198,6 @@ class System(ModelingObject):
                         for usage_pattern in self.usage_patterns},
             "EdgeDevices": {edge_device: edge_device.energy_footprint
                             for edge_device in self.edge_devices},
-            "EdgeStorage": {edge_storage: edge_storage.energy_footprint for edge_storage in self.edge_storages},
         }
 
         return energy_footprints
@@ -212,9 +218,6 @@ class System(ModelingObject):
             "EdgeDevices": sum([edge_device.instances_fabrication_footprint for edge_device in self.edge_devices],
                                start=EmptyExplainableObject()).to(u.kg).set_label(
                 "Edge devices total fabrication footprint"),
-            "EdgeStorage": sum([edge_storage.instances_fabrication_footprint for edge_storage in self.edge_storages],
-                                start=EmptyExplainableObject()).to(u.kg).set_label(
-                "Edge storage total fabrication footprint")
         }
 
         return fab_footprints
@@ -232,8 +235,6 @@ class System(ModelingObject):
                            start=EmptyExplainableObject()).to(u.kg).set_label("Devices total energy footprint"),
             "EdgeDevices": sum([edge_device.energy_footprint for edge_device in self.edge_devices],
                                start=EmptyExplainableObject()).to(u.kg).set_label("Edge devices total energy footprint"),
-            "EdgeStorage": sum([edge_storage.energy_footprint for edge_storage in self.edge_storages],
-                               start=EmptyExplainableObject()).to(u.kg).set_label("Edge storage total energy footprint")
         }
 
         return energy_footprints
