@@ -1,5 +1,15 @@
 import time
 
+from functools import lru_cache
+from inspect import signature
+
+from efootprint.logger import logger
+
+
+@lru_cache(maxsize=None)
+def get_init_signature_params(cls):
+    return signature(cls.__init__).parameters
+
 
 def round_dict(my_dict, round_level):
     for key in my_dict:
@@ -8,39 +18,18 @@ def round_dict(my_dict, round_level):
     return my_dict
 
 
-def flatten_list(nested_list):
-    flattened_list = [item for sublist in nested_list
-                      for item in (flatten_list(sublist) if isinstance(sublist, list) else [sublist])]
-    for elt in flattened_list:
-        if type(elt) == set:
-            raise ValueError("flatten_list function is not supposed to handle set elements, please refactor it.")
-
-    return flattened_list
-
-
 def time_it(func):
     def wrapper(*args, **kwargs):
         start_time = time.time()
         result = func(*args, **kwargs)
         end_time = time.time()
         diff = end_time - start_time
-        if diff > 0.001:
-            print(f"Function {func.__name__} took {diff:.5f} seconds to execute.")
+        if diff > 0.000001:
+            logger.info(f"Function {func.__name__} took {diff*1000:.3f} ms to execute.")
         return result
     return wrapper
 
 
-def convert_to_list(input_value):
-    if type(input_value) == list:
-        value_elts = flatten_list(input_value)
-    elif type(input_value) == set:
-        value_elts = flatten_list(list(input_value))
-    else:
-        value_elts = [input_value]
-
-    return value_elts
-
-
 def format_co2_amount(co2_amount_in_kg: int, rounding_value=1):
     if co2_amount_in_kg < 501:
         unit = "kg"
